# 🌀 bluer-south

AI for Global South: Free from Big Tech.

```bash
pip install bluer-south
```

|   |   |   |
| --- | --- | --- |
| [`bluer_ai`](https://github.com/kamangir/bluer-ai) [![image](https://github.com/kamangir/assets/blob/main/awesome-bash-cli/marquee-2024-10-26.jpg?raw=true)](https://github.com/kamangir/bluer-ai) A language to speak AI.  [![PyPI version](https://img.shields.io/pypi/v/bluer_ai.svg)](https://pypi.org/project/bluer_ai/) | [`bluer_options`](https://github.com/kamangir/bluer-options) [![image](https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true)](https://github.com/kamangir/bluer-options) options for Bash.  [![PyPI version](https://img.shields.io/pypi/v/bluer_options.svg)](https://pypi.org/project/bluer_options/) | [`bluer_objects`](https://github.com/kamangir/bluer-objects) [![image](https://github.com/kamangir/assets/raw/main/blue-objects/marquee.png?raw=true)](https://github.com/kamangir/bluer-objects) data objects for Bash.  [![PyPI version](https://img.shields.io/pypi/v/bluer_objects.svg)](https://pypi.org/project/bluer_objects/) |
| [`bluer_plugin`](https://github.com/kamangir/bluer-plugin) [![image](https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true)](https://github.com/kamangir/bluer-plugin) a git template for a bluer-ai plugin.  [![PyPI version](https://img.shields.io/pypi/v/bluer_plugin.svg)](https://pypi.org/project/bluer_plugin/) | [`bluer_sbc`](https://github.com/kamangir/bluer-sbc) [![image](https://github.com/kamangir/blue-bracket/blob/main/images/helmet-3.jpg)](https://github.com/kamangir/bluer-sbc) AI for single board computers.  [![PyPI version](https://img.shields.io/pypi/v/bluer_sbc.svg)](https://pypi.org/project/bluer_sbc/) | [`gizai`](https://github.com/kamangir/giza) [![image](https://github.com/kamangir/giza/raw/main/assets/giza.png)](https://github.com/kamangir/giza) Access, Automation, Analytics, AI - A Mathematical model for AI languages.  [![PyPI version](https://img.shields.io/pypi/v/gizai.svg)](https://pypi.org/project/gizai/) |

---


[![pylint](https://github.com/kamangir/bluer-south/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/bluer-south/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/bluer-south/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/bluer-south/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/bluer-south/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/bluer-south/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/bluer-south.svg)](https://pypi.org/project/bluer-south/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/bluer-south)](https://pypistats.org/packages/bluer-south)

built by 🌀 [`bluer_options-5.35.1`](https://github.com/kamangir/awesome-bash-cli), based on 🌀 [`bluer_south-4.41.1`](https://github.com/kamangir/bluer-south).
